@@ -63,6 +63,7 @@ that Ediff doesn't know about.")
 (defun ediff-has-face-support-p ()
   (cond ((ediff-window-display-p))
 	(ediff-force-faces)
+	((ediff-color-display-p))
 	(ediff-emacs-p (memq (ediff-device-type) '(pc)))
 	(ediff-xemacs-p (memq (ediff-device-type) '(tty pc)))))
 
@@ -738,22 +739,15 @@ appropriate symbol: `rcs', `pcl-cvs', or `generic-sc' if you so desire."
 	  ((memq op '(< <=)) t))))
   
   
-
-;; A fix for NeXT Step
-;; Should probably be eliminated in later versions.
-(if (and (ediff-window-display-p) (eq (ediff-device-type) 'ns))
-    (progn
-      (fset 'x-display-color-p (symbol-function 'ns-display-color-p))
-      (fset 'x-color-defined-p (symbol-function 'ns-color-defined-p))
-      (fset 'x-display-pixel-height (symbol-function 'ns-display-pixel-height))
-      (fset 'x-display-pixel-width (symbol-function 'ns-display-pixel-width))
-      ))
-
-
-(defsubst ediff-color-display-p ()
-  (if ediff-emacs-p
-      (x-display-color-p)
-    (eq (device-class (selected-device)) 'color)))
+(defun ediff-color-display-p ()
+  (condition-case nil
+      (if ediff-emacs-p
+	  (if (fboundp 'display-color-p)
+	      (display-color-p)
+	    (x-display-color-p))
+	(eq (device-class (selected-device)) 'color))
+    (error
+     nil)))
 
   
 (if (ediff-has-face-support-p)
@@ -761,12 +755,10 @@ appropriate symbol: `rcs', `pcl-cvs', or `generic-sc' if you so desire."
 	(progn
 	  (fset 'ediff-valid-color-p (symbol-function 'valid-color-name-p))
 	  (fset 'ediff-get-face (symbol-function 'get-face)))
-      ;; Temporary fix for OS/2 port of Emacs
-      ;; pm-win.el in PM-Emacs should be fixed.
-      (if (eq (ediff-device-type) 'pm)
-	  (fset 'ediff-valid-color-p 
-		(lambda (color) (assoc color pm-color-alist)))
-	(fset 'ediff-valid-color-p (symbol-function 'x-color-defined-p)))
+      (fset 'ediff-valid-color-p (symbol-function
+				  (if (fboundp 'color-defined-p)
+				      'color-defined-p
+				    'x-color-defined-p)))
       (fset 'ediff-get-face (symbol-function 'internal-get-face))))
 
 (if (ediff-window-display-p)
@@ -776,10 +768,14 @@ appropriate symbol: `rcs', `pcl-cvs', or `generic-sc' if you so desire."
 		(symbol-function 'device-pixel-width))
 	  (fset 'ediff-display-pixel-height
 		(symbol-function 'device-pixel-height)))
-      (fset 'ediff-display-pixel-width 
-	    (symbol-function 'x-display-pixel-width))
-      (fset 'ediff-display-pixel-height
-	    (symbol-function 'x-display-pixel-height))))
+      (fset 'ediff-display-pixel-width (symbol-function
+					(if (fboundp 'display-pixel-width)
+					    'display-pixel-width
+					  'x-display-pixel-width)))
+      (fset 'ediff-display-pixel-height (symbol-function
+					 (if (fboundp 'display-pixel-height)
+					     'display-pixel-height
+					   'x-display-pixel-height)))))
       
 ;; A-list of current-diff-overlay symbols asssociated with buf types
 (defconst ediff-current-diff-overlay-alist
@@ -1206,6 +1202,11 @@ as `ediff-merge-directory' or `ediff-merge-directory-revisions'."
 
 ;; file where the result of the merge is to be saved.  used internally
 (ediff-defvar-local ediff-merge-store-file nil "")
+
+(defcustom ediff-merge-filename-prefix "merge_"
+  "*Prefix to be attached to saved merge buffers."
+  :type 'string
+  :group 'ediff-merge)
   
 (defcustom ediff-no-emacs-help-in-control-buffer nil
   "*Non-nil means C-h should not invoke Emacs help in control buffer.
